Setting up Shopyo
=================
🔧 Install instructions
-----------------------

- download python3.7
- clone and cd into project
- run

.. code-block:: python
   :caption: Install requirements.
   :name:  install_requirements

    python -m pip install -r requirements.txt

👟 Run instructions
-------------------

``cd`` into shopyo/shopyo if not already.

initialise and setup app.

.. code-block:: python
   :caption: initialise Shopyo.
   :name: initialise

    python manage.py initialise

run the app.

.. code-block:: python
   :caption: runserver.
   :name: runserver

    python manage.py runserver

go to the indicated url

**Super User password**
-----------------------

.. code-block:: python
   :caption: super user password.
   :name: user_pass

    User ID: user
    password: pass

